--[[
	ESOAttributeNotify
	==========================================
	An addon that notifies players when they have unspent skill or attributes.
	==========================================
	Written by Sean McKeown - 4/9/2014
]]--

ESOAttributeNotify = {}

ESOAttributeNotify.name = "ESOAttributeNotify"
ESOAttributeNotify.command = "/attributenotify"
ESOAttributeNotify.version = "v1.0.2"

local skillPoints = 0
local attributePoints = 0

local recentSkill = 0
local recentAttribute = 0

local display = true

local timer = 0
local lastUpdate = 5

function ESOAttributeNotify.Initialize( eventCode, addOnName )

	if ( addOnName ~= ESOAttributeNotify.name ) then
		return
	end
	
	EVENT_MANAGER:RegisterForEvent( ESOAttributeNotify.name,  EVENT_SKILL_POINTS_CHANGED, ESOAttributeNotify.Update() )
	
end

function isPlural(number)

	if(number == 1) then
		return ""
	else
		return "s"
	end
	
end

function ESOAttributeNotify.Hide()
	
	display = false
	
end

function ESOAttributeNotify.Timer()

	if(timer >= 5 and lastUpdate >= 5) then
		timer = 0
		ESOAttributeNotify.Update()
	end
	
	timer = timer + 1
	
end
	

function ESOAttributeNotify.Update()

	lastUpdate = 0
	
	attributePoints = GetAttributeUnspentPoints()
	skillPoints = GetAvailableSkillPoints()

	if(attributePoints ~= recentAttribute or skillPoints ~= recentSkill) then
		if(attributePoints ~= 0 or skillPoints ~= 0) then
			display = true
		end
	end
	
	if(display == false) then
		ESOAttributeNotifyUInotify:SetText(string.format(""))
	end

	if(display == true) then
		if(skillPoints > 0 and attributePoints > 0) then
			ESOAttributeNotifyUInotify:SetText(string.format("You have %d skill point%s and %d attribute point%s available.",  skillPoints, isPlural(skillPoints), attributePoints, isPlural(attributePoints)))
		elseif(skillPoints > 0 and attributePoints == 0) then
			ESOAttributeNotifyUInotify:SetText(string.format("You have %d skill point%s available.",  skillPoints, isPlural(skillPoints)))
		elseif(skillPoints == 0 and attributePoints > 0) then
			ESOAttributeNotifyUInotify:SetText(string.format("You have %d attribute point%s available.",  attributePoints, isPlural(attributePoints)))
		else
			ESOAttributeNotifyUInotify:SetText(string.format(""))
		end
	end
	
	recentSkill = skillPoints
	recentAttribute = attributePoints
	
end